Module error

Module error 

The Err type

Structs

PdnsAPIError
PowerDNS API error response.

Enums

Error
The error type. This is an enum describing all possible errors returnable. Unless otherwise specified, assume that a public/exported function returning this enum can return any of its variants.