pub struct Server {
pub id: String,
pub daemon_type: String,
pub version: String,
pub server_type: String,
pub url: String,
pub config_url: String,
pub zones_url: String,
pub autoprimaries: String,
}Expand description
The server information returned by pdns API. Note, crucially, this does not contain any information about the client (and thus the pdns webserver) used to retrieve this information. As a result, users may want to ensure that servers being compared, are retrieved from the same client/pdns webserver.
Fields
id: Stringserver id
daemon_type: Stringdaemon type
version: Stringserver version
server_type: Stringserver type
url: Stringserver url
config_url: Stringserver’s config url
zones_url: Stringserver’s zone url
autoprimaries: Stringserver’s automprimaries url