The Err type
Structs
- PdnsAPI
Error PowerDNSAPI error response.
Enums
- Error
- The error type. This is an enum describing all possible errors returnable. Unless otherwise specified, assume that a public/exported function returning this enum can return any of its variants.